fn interpolate_deltas<C, D>(
points: &[Point<C>],
flags: &[PointFlags],
contours: &[u16],
out_points: &mut [Point<D>],
) -> Option<()>Expand description
Interpolates the points that the current tuple did not reference, in the
manner of the IUP hinting instruction.
Points carrying an explicit delta are marked with PointMarker::HAS_DELTA
in flags. Each contour is handled independently.
Modeled after the FreeType implementation: https://github.com/freetype/freetype/blob/bbfcd79eacb4985d4b68783565f4b494aa64516b/src/truetype/ttgxvar.c#L3881